@@ -15,8 +15,10 @@ import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
 import java.nio.file.attribute.FileTime;
+import java.util.EnumSet;
 import java.util.Observable;
 import java.util.Properties;
+import java.util.Set;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
@@ -113,6 +115,11 @@ public class Configuration extends Observable implements Cloneable {
     return props.getProperty(key);
   }
 
+  /** Retrieves the value for key returning a default for non-existing keys. */
+  public String getProperty(String key, String def) {
+    return props.getProperty(key, def);
+  }
+
   /** Sets the value for key. */
   public void setProperty(String key, String value) {
     props.setProperty(key, value);
@@ -245,6 +252,30 @@ public class Configuration extends Observable implements Cloneable {
     }
   }
 
+  /**
+   * Returns a {@code SourceType} as List, e.g.
+   * {@code sourcetypeproperty = Remote, Sync}.
+   */
+  public Set<SourceType> getSourceTypeSet(Key key) throws ConfigurationException {
+    Set<SourceType> res = null;
+    try {
+      checkClass(key, SourceType[].class);
+      String[] interim = props.getProperty(key.name()).split(FIELDSEP);
+      for (int i = 0; i < interim.length; i++) {
+        SourceType st = SourceType.valueOf(interim[i].trim());
+        if (null == res) {
+          res = EnumSet.of(st);
+        } else {
+          res.add(st);
+        }
+      }
+      return res;
+    } catch (RuntimeException re) {
+      throw new ConfigurationException("Corrupt property: " + key
+          + " reason: " + re.getMessage(), re);
+    }
+  }
+
   /**
    * Returns a {@code URL} property, e.g.
    * {@code urlProperty = https://my.url.here}.
@@ -253,10 +284,30 @@ public class Configuration extends Observable implements Cloneable {
     try {
       checkClass(key, URL.class);
       return new URL(props.getProperty(key.name()));
-    } catch (MalformedURLException mue) {
+    } catch (MalformedURLException | RuntimeException mue) {
       throw new ConfigurationException("Corrupt property: " + key
           + " reason: " + mue.getMessage(), mue);
     }
   }
 
+  /**
+   * Returns {@code URL[]} from a property. Commas seperate array elements,
+   * e.g.,
+   * {@code propertyname = a1.example.org, a2.example2.com, a3.example3.net}
+   */
+  public URL[] getUrlArray(Key key) throws ConfigurationException {
+    try {
+      checkClass(key, URL[].class);
+      String[] interim = props.getProperty(key.name()).split(FIELDSEP);
+      URL[] res = new URL[interim.length];
+      for (int i = 0; i < interim.length; i++) {
+        res[i] = new URL(interim[i].trim());
+      }
+      return res;
+    } catch (MalformedURLException | RuntimeException re) {
+      throw new ConfigurationException("Corrupt property: " + key
+          + " reason: " + re.getMessage(), re);
+    }
+  }
+
 }
