@@ -19,12 +19,14 @@ import org.junit.rules.TemporaryFolder;
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.lang.reflect.Field;
+import java.net.URL;
 import java.nio.file.Files;
 import java.nio.file.Paths;
 import java.util.Arrays;
 import java.util.Observable;
 import java.util.Observer;
 import java.util.Random;
+import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 public class ConfigurationTest {
@@ -38,16 +40,16 @@ public class ConfigurationTest {
   public void testKeyCount() throws Exception {
     assertEquals("The number of properties keys in enum Key changed."
         + "\n This test class should be adapted.",
-        49, Key.values().length);
+        44, Key.values().length);
   }
 
   @Test()
   public void testConfiguration() throws Exception {
     Configuration conf = new Configuration();
     String val = "xyz";
-    conf.setProperty(Key.TorperfOutputDirectory.name(), val);
+    conf.setProperty(Key.OutputPath.name(), val);
     assertEquals(1, conf.size());
-    assertEquals(val, conf.getProperty(Key.TorperfOutputDirectory.name()));
+    assertEquals(val, conf.getProperty(Key.OutputPath.name()));
   }
 
   private String propLine(Key key, String val) {
@@ -68,11 +70,11 @@ public class ConfigurationTest {
     Configuration conf = new Configuration();
     for (String input : arrays) {
       conf.clear();
-      conf.setProperty(Key.CachedRelayDescriptorsDirectories.name(), input);
+      conf.setProperty(Key.RelayCacheOrigins.name(), input);
       assertArrayEquals("expected " + Arrays.toString(array) + "\nreceived: "
           + Arrays.toString(conf
-              .getStringArray(Key.CachedRelayDescriptorsDirectories)),
-          array, conf.getStringArray(Key.CachedRelayDescriptorsDirectories));
+              .getStringArray(Key.RelayCacheOrigins)),
+          array, conf.getStringArray(Key.RelayCacheOrigins));
     }
   }
 
@@ -80,10 +82,10 @@ public class ConfigurationTest {
   public void testBoolValues() throws Exception {
     Configuration conf = new Configuration();
     conf.setProperty(Key.CompressRelayDescriptorDownloads.name(), "false");
-    conf.setProperty(Key.ImportDirectoryArchives.name(), "trUe");
+    conf.setProperty(Key.RunOnce.name(), "trUe");
     conf.setProperty(Key.ReplaceIpAddressesWithHashes.name(), "false");
     assertFalse(conf.getBool(Key.CompressRelayDescriptorDownloads));
-    assertTrue(conf.getBool(Key.ImportDirectoryArchives));
+    assertTrue(conf.getBool(Key.RunOnce));
     assertFalse(conf.getBool(Key.ReplaceIpAddressesWithHashes));
   }
 
@@ -108,9 +110,22 @@ public class ConfigurationTest {
     Configuration conf = new Configuration();
     for (String file : files) {
       conf.clear();
-      conf.setProperty(Key.DirectoryArchivesOutputDirectory.name(), file);
+      conf.setProperty(Key.OutputPath.name(), file);
       assertEquals(new File(file),
-          conf.getPath(Key.DirectoryArchivesOutputDirectory).toFile());
+          conf.getPath(Key.OutputPath).toFile());
+    }
+  }
+
+  @Test()
+  public void testSourceTypeValues() throws Exception {
+    String[] types = new String[] { "Local", "Cache", "Remote", "Sync"};
+    Configuration conf = new Configuration();
+    for (String type : types) {
+      conf.clear();
+      conf.setProperty(Key.BridgeSources.name(), type);
+      Set<SourceType> sts = conf.getSourceTypeSet(Key.BridgeSources);
+      assertEquals(1, sts.size());
+      assertTrue(sts.contains(SourceType.valueOf(type)));
     }
   }
 
@@ -120,39 +135,58 @@ public class ConfigurationTest {
       new String[]{"localsource", "http://127.0.0.1:12345"},
       new String[]{"somesource", "https://some.host.org:12345"}};
     Configuration conf = new Configuration();
-    conf.setProperty(Key.TorperfSources.name(),
+    conf.setProperty(Key.TorperfHosts.name(),
         Arrays.deepToString(sourceStrings).replace("[[", "").replace("]]", "")
             .replace("], [", Configuration.ARRAYSEP));
     assertArrayEquals(sourceStrings,
-        conf.getStringArrayArray(Key.TorperfSources));
+        conf.getStringArrayArray(Key.TorperfHosts));
+  }
+
+  @Test()
+  public void testUrlArrayValues() throws Exception {
+    URL[] array = new URL[randomSource.nextInt(30) + 1];
+    for (int i = 0; i < array.length; i++) {
+      array[i] = new URL("https://"
+          + Integer.toBinaryString(randomSource.nextInt(100)) + ".dummy.org");
+    }
+    String input =
+        Arrays.toString(array).replace("[", "").replace("]", "")
+            .replaceAll(" ", "");
+    Configuration conf = new Configuration();
+    conf.clear();
+    conf.setProperty(Key.RelaySyncOrigins.name(), input);
+    assertArrayEquals("expected " + Arrays.toString(array) + "\nreceived: "
+        + Arrays.toString(conf
+            .getUrlArray(Key.RelaySyncOrigins)),
+        array, conf.getUrlArray(Key.RelaySyncOrigins));
   }
 
   @Test(expected = ConfigurationException.class)
   public void testArrayArrayValueException() throws Exception {
     Configuration conf = new Configuration();
-    conf.setProperty(Key.CachedRelayDescriptorsDirectories.name(), "");
-    conf.getStringArrayArray(Key.TorperfOutputDirectory);
+    conf.setProperty(Key.RelayCacheOrigins.name(), "");
+    conf.getStringArrayArray(Key.OutputPath);
   }
 
   @Test(expected = ConfigurationException.class)
   public void testArrayValueException() throws Exception {
     Configuration conf = new Configuration();
-    conf.setProperty(Key.CachedRelayDescriptorsDirectories.name(), "");
-    conf.getStringArray(Key.TorperfSources);
+    conf.setProperty(Key.RelayCacheOrigins.name(), "");
+    conf.getStringArray(Key.TorperfHosts);
   }
 
   @Test(expected = ConfigurationException.class)
   public void testBoolValueException() throws Exception {
     Configuration conf = new Configuration();
-    conf.setProperty(Key.TorperfSources.name(), "http://x.y.z");
-    conf.getBool(Key.CachedRelayDescriptorsDirectories);
+    conf.setProperty(Key.TorperfHosts.name(), "http://x.y.z");
+    conf.getBool(Key.RelayCacheOrigins);
   }
 
   @Test(expected = ConfigurationException.class)
   public void testPathValueException() throws Exception {
     Configuration conf = new Configuration();
-    conf.setProperty(Key.DirectoryArchivesDirectory.name(), "\\\u0000:");
-    conf.getPath(Key.DirectoryArchivesDirectory);
+    conf.setProperty(Key.RelayLocalOrigins.name(), "\\\u0000:");
+    conf.getPath(Key.RelayLocalOrigins);
   }
 
   @Test(expected = ConfigurationException.class)
@@ -212,7 +246,7 @@ public class ConfigurationTest {
     conf.setWatchableSourceAndLoad(confFile.toPath());
     MainTest.waitSec(1);
     confFile.delete();
-    conf.setProperty(Key.ImportDirectoryArchives.name(), "false");
+    conf.setProperty(Key.RunOnce.name(), "false");
     final Dummy dummy = new Dummy(conf);
     tmpf.newFolder("empty");
     MainTest.waitSec(6);
