@@ -3,11 +3,6 @@
 
 package org.torproject.collector.bridgedescs;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-
 import org.torproject.collector.conf.Configuration;
 
 import org.junit.Test;
